import { Graph, LayoutMapping, FruchtermanLayoutOptions, Layout } from "@antv/layout";
/**
 * Layout with fructherman force model
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new FruchtermanLayout({ center: [100, 100] });
 * const positions = await layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new FruchtermanLayout({ center: [100, 100] });
 * const positions = await layout.execute(graph, { center: [100, 100] }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * await layout.assign(graph, { center: [100, 100] });
 */
export declare class FruchtermanLayout implements Layout<FruchtermanLayoutOptions> {
    options: FruchtermanLayoutOptions;
    id: string;
    constructor(options?: FruchtermanLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: FruchtermanLayoutOptions): Promise<LayoutMapping>;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: FruchtermanLayoutOptions): Promise<void>;
    private genericFruchtermanLayout;
    private formatOptions;
}
