import { Graph, LayoutMapping, ForceLayoutOptions, Layout } from "@antv/layout";
/**
 * Layout with faster force
 *
 * @example
 * // Assign layout options when initialization.
 * const layout = new GForceLayout({ center: [100, 100], onLayoutEnd: (positions) => {} });
 * const positions = await layout.execute(graph); // { nodes: [], edges: [] }
 *
 * // Or use different options later.
 * const layout = new GForceLayout({ center: [100, 100], onLayoutEnd: (positions) => {} });
 * const positions = await layout.execute(graph, { center: [100, 100] }); // { nodes: [], edges: [] }
 *
 * // If you want to assign the positions directly to the nodes, use assign method.
 * await layout.assign(graph, { center: [100, 100] });
 */
export declare class GForceLayout implements Layout<ForceLayoutOptions> {
    options: ForceLayoutOptions;
    id: string;
    constructor(options?: ForceLayoutOptions);
    /**
     * Return the positions of nodes and edges(if needed).
     */
    execute(graph: Graph, options?: ForceLayoutOptions): Promise<LayoutMapping>;
    /**
     * To directly assign the positions to the nodes.
     */
    assign(graph: Graph, options?: ForceLayoutOptions): Promise<void>;
    private genericForceLayout;
    private formatOptions;
}
